require 'test_helper'

class ArrayedFieldTest < ActionView::TestCase
  include BootstrapFormExtensions::ArrayedField

  def setup
    setup_test_fixture
  end

  test "arrayed_text_field with default values" do
    expected = '<div class="form-group row"><label class="col-form-label col-2" for="thing_list">List</label><div class="col-10"><div data-arrayed-field="true"><div class="blueprint-for-arrayed-field" style="display:none;"><div class="row mt-1"><div class="col"><input type="text" id="" class="form-control" data-name="thing[list][]" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="arrayed-field-rows"><div class="row mt-1"><div class="col"><input type="text" name="thing[list][]" id="thing_list_" value="One" class="form-control" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div><div class="row mt-1"><div class="col"><input type="text" name="thing[list][]" id="thing_list_" value="Two" class="form-control" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="row mt-1"><div class="col-12"><a class="btn btn-outline-primary add-arrayed-field-row" href="javascript:void(0);">+</a></div></div></div></div></div>'
    assert_equal expected, @builder.arrayed_text_field(:list)
  end

  test "arrayed_url_field with default values" do
    expected = '<div class="form-group row"><label class="col-form-label col-2" for="thing_urls">Urls</label><div class="col-10"><div data-arrayed-field="true"><div class="blueprint-for-arrayed-field" style="display:none;"><div class="row mt-1"><div class="col"><input type="url" id="" class="form-control" data-name="thing[urls][]" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="arrayed-field-rows"><div class="row mt-1"><div class="col"><input type="url" name="thing[urls][]" id="thing_urls_" value="www.example1.com" class="form-control" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div><div class="row mt-1"><div class="col"><input type="url" name="thing[urls][]" id="thing_urls_" value="www.example2.com" class="form-control" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="row mt-1"><div class="col-12"><a class="btn btn-outline-primary add-arrayed-field-row" href="javascript:void(0);">+</a></div></div></div></div></div>'
    assert_equal expected, @builder.arrayed_url_field(:urls)
  end

  test "ArrayedField, with nonexistent attribute, assumes the value is an empty array" do
    expected = '<div class="form-group row"><label class="col-form-label col-2" for="thing_nonexistent">Nonexistent</label><div class="col-10"><div data-arrayed-field="true"><div class="blueprint-for-arrayed-field" style="display:none;"><div class="row mt-1"><div class="col"><input type="text" id="" class="form-control" data-name="thing[nonexistent][]" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="arrayed-field-rows"></div><div class="row mt-1"><div class="col-12"><a class="btn btn-outline-primary add-arrayed-field-row" href="javascript:void(0);">+</a></div></div></div></div></div>'
    assert_equal expected, @builder.arrayed_text_field(:nonexistent)
  end

  test "ArrayedField, with non-array attribute, assumes the value is an empty array" do
    expected = '<div class="form-group row"><label class="col-form-label col-2 required" for="thing_name">Name</label><div class="col-10"><div data-arrayed-field="true"><div class="blueprint-for-arrayed-field" style="display:none;"><div class="row mt-1"><div class="col"><input type="text" id="" class="form-control" data-name="thing[name][]" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="arrayed-field-rows"></div><div class="row mt-1"><div class="col-12"><a class="btn btn-outline-primary add-arrayed-field-row" href="javascript:void(0);">+</a></div></div></div></div></div>'
    assert_equal expected, @builder.arrayed_text_field(:name)
  end

  test "pass options to the form group in the an ArrayedField" do
    @output_buffer = @builder.arrayed_text_field(:list, wrapper_class: 'extra-class')
    assert_select 'div.form-group.extra-class'
  end

  test "arrayed_json_field with default values" do
    expected = '<div class="form-group row"><label class="col-form-label col-2" for="thing_variables">Variables</label><div class="col-10"><div data-arrayed-field="true"><div class="blueprint-for-arrayed-field" style="display:none;"><div class="row mt-1"><div class="col-2"><input type="text" id="" class="form-control" placeholder="name" data-name="thing[variables][][name]" /></div><div class="col-2"><input type="text" id="" class="form-control" placeholder="value" data-name="thing[variables][][value]" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="arrayed-field-rows"><div class="row mt-1"><div class="col-2"><input type="text" name="thing[variables][][name]" id="thing_variables__name" class="form-control" placeholder="name" /></div><div class="col-2"><input type="text" name="thing[variables][][value]" id="thing_variables__value" class="form-control" placeholder="value" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div><div class="row mt-1"><div class="col-2"><input type="text" name="thing[variables][][name]" id="thing_variables__name" class="form-control" placeholder="name" /></div><div class="col-2"><input type="text" name="thing[variables][][value]" id="thing_variables__value" class="form-control" placeholder="value" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="row mt-1"><div class="col-12"><a class="btn btn-outline-primary add-arrayed-field-row" href="javascript:void(0);">+</a></div></div></div></div></div>'
    assert_equal expected, @builder.arrayed_json_field(:variables, %i[ name value ])
  end

  test "arrayed_json_field with custom input types" do
    expected = <<-HTML.chomp
<div class="form-group row"><label class="col-form-label col-2" for="thing_variables">Variables</label><div class="col-10"><div data-arrayed-field="true"><div class="blueprint-for-arrayed-field" style="display:none;"><div class="row mt-1"><div class="col-2"><select id="" class="form-control" data-name="thing[variables][][name]"><option value="var1">Variable One</option>
<option value="var2">Variable Two</option>
<option value="var3">Variable Three</option></select></div><div class="col-2"><input type="text" id="" class="form-control" placeholder="value" data-name="thing[variables][][value]" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="arrayed-field-rows"><div class="row mt-1"><div class="col-2"><select name="thing[variables][][name]" id="thing_variables__name" class="form-control"><option value="var1">Variable One</option>
<option value="var2">Variable Two</option>
<option value="var3">Variable Three</option></select></div><div class="col-2"><input type="text" name="thing[variables][][value]" id="thing_variables__value" class="form-control" placeholder="value" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div><div class="row mt-1"><div class="col-2"><select name="thing[variables][][name]" id="thing_variables__name" class="form-control"><option value="var1">Variable One</option>
<option value="var2">Variable Two</option>
<option value="var3">Variable Three</option></select></div><div class="col-2"><input type="text" name="thing[variables][][value]" id="thing_variables__value" class="form-control" placeholder="value" /></div><div class="col-auto ml-auto"><a class="btn btn-outline-danger remove-arrayed-field-row" href="javascript:void(0);">&times;</a></div></div></div><div class="row mt-1"><div class="col-12"><a class="btn btn-outline-primary add-arrayed-field-row" href="javascript:void(0);">+</a></div></div></div></div></div>
    HTML
    assert_equal expected, @builder.arrayed_json_field(:variables, [ { name: { type: :select, options: options_for_variables } }, :value ])
  end

  private

  def options_for_variables
    [
      [ "Variable One",   "var1" ],
      [ "Variable Two",   "var2" ],
      [ "Variable Three", "var3" ],
    ]
  end

end
